@@ -53,7 +53,7 @@ impl ImageList {
                                 t_index.store(index, Ordering::SeqCst);
                             }
                             match dir.path().extension() {
-                                Some(ext) if EXTENSIONS.contains(ext.to_str().unwrap()) => {
+                                Some(ext) if EXTENSIONS.contains(&*ext.to_string_lossy().to_ascii_lowercase()) => {
                                     list.push(path)
                                 }
                                 _ => (),
